import { Application, View } from "@nativescript/core";
import { warn, } from "@vue/runtime-core";
import { isObject } from "@vue/shared";
import { NSVElement } from "../dom";
import { createNativeView } from "../runtimeHelpers";
/**
 * @internal
 */
export function install(app) {
    app.config.globalProperties.$showModal = $showModal;
}
function resolveModalTarget(target) {
    if (isObject(target) && isObject(target.$el)) {
        return target.$el.nativeView;
    }
    else if (target instanceof NSVElement) {
        return target.nativeView;
    }
    else if (target instanceof View) {
        return target;
    }
    return false;
}
export async function $showModal(component, options) {
    options = Object.assign({
        target: Application.getRootView(),
    }, options);
    const modalTarget = resolveModalTarget(options.target);
    if (!modalTarget) {
        if (__DEV__) {
            warn(`could not open modal because the target does not exist`);
        }
        return;
    }
    return new Promise((resolve) => {
        let isResolved = false;
        let view = createNativeView(component, options.props);
        const closeModal = (...args) => modalContent.closeModal(...args);
        const closeCallback = (data) => {
            if (isResolved)
                return;
            isResolved = true;
            view.unmount();
            view = null;
            resolve(data);
        };
        view.context.config.globalProperties.$closeModal = closeModal;
        view.context.config.globalProperties.$modal = { close: closeModal };
        const modalContent = view.mount();
        modalTarget.showModal(modalContent, {
            ...options,
            context: null,
            closeCallback,
        });
    });
}
//# sourceMappingURL=modals.js.map